import React, { useState } from 'react';
import { Modal, Form, Select, Button, Row, Col, Card, Typography } from 'antd';
import { CloseOutlined, PlusOutlined, EditOutlined, PlayCircleOutlined } from '@ant-design/icons';
import VideoSelectModal from '../videoSelectModal'; // Import the new component

const { Option } = Select;
const { Text } = Typography;

interface VideoItem {
	id: number;
	source: string;
	title: string;
	thumbnail: string; // URL to thumbnail image
	spreadEfficiency: number;
}

interface AddPunlishPlanModalProps {
	visible: boolean;
	onCancel: () => void;
	onOk: (values: any) => void; // Pass form values on OK
}

const AddPunlishPlanModal: React.FC<AddPunlishPlanModalProps> = ({ visible, onCancel, onOk }) => {
	const [form] = Form.useForm();
	const [selectedVideos, setSelectedVideos] = useState<VideoItem[]>([]); // Start with empty selection
	const [isVideoSelectVisible, setIsVideoSelectVisible] = useState(false);

	const handleOk = () => {
		form
			.validateFields()
			.then((values) => {
				// Ensure at least one video is selected before submitting
				if (selectedVideos.length === 0) {
					// Optionally show a message to the user
					console.error('Please select at least one video.');
					return;
				}
				onOk({ ...values, videos: selectedVideos });
			})
			.catch((info) => {
				console.log('Validate Failed:', info);
			});
	};

	const removeVideo = (idToRemove: number) => {
		setSelectedVideos(currentVideos => currentVideos.filter(video => video.id !== idToRemove));
	};

	const openVideoSelector = () => {
		setIsVideoSelectVisible(true);
	};

	const handleVideoSelectionOk = (newlySelectedVideos: VideoItem[]) => {
		setSelectedVideos(newlySelectedVideos);
		setIsVideoSelectVisible(false);
	};

	const handleVideoSelectionCancel = () => {
		setIsVideoSelectVisible(false);
	};

	return (
		<>
			<Modal
				title="创建发布计划"
				open={visible}
				onCancel={onCancel}
				width={800} // Adjust width as needed
				footer={[
					<Button key="back" onClick={onCancel}>
						取消
					</Button>,
					<Button key="submit" type="primary" onClick={handleOk}>
						确定
					</Button>,
				]}
			>
				<Form form={form} layout="vertical">
					<Row gutter={16}>
						<Col span={12}>
							<Form.Item
								name="publisher"
								label="发布方"
								rules={[{ required: true, message: '请选择发布方' }]}
							>
								<Select placeholder="选择发布方">
									<Option value="platform">平台发布</Option>
									<Option value="user">用户发布</Option>
								</Select>
							</Form.Item>
						</Col>
						<Col span={12}>
							<Form.Item
								name="officialAccount"
								label="公众号名称"
								rules={[{ required: true, message: '请选择公众号' }]}
							>
								<Select placeholder="选择公众号">
									<Option value="account1">小慧爱厨房</Option>
									<Option value="account2">小阳看天下</Option>
									{/* Add more options as needed */}
								</Select>
							</Form.Item>
						</Col>
					</Row>

					<Form.Item label="发布场景">
						<Text>关注回复</Text>
					</Form.Item>

					<Form.Item label="发布内容" required>
						<div className="flex flex-wrap gap-4">
							{selectedVideos.map((video) => (
								<Card
									key={video.id}
									className="w-[220px] relative group"
									bodyStyle={{ padding: 0 }}
								>
									<Button
										shape="circle"
										icon={<CloseOutlined />}
										className="absolute top-1 right-1 z-10 bg-gray-400 bg-opacity-50 border-none text-white hidden group-hover:inline-flex justify-center items-center"
										size="small"
										onClick={() => removeVideo(video.id)}
									/>
									<div className="p-3">
										<Text type="secondary" className="text-xs">{video.source}</Text>
										<Text className="block mt-1 mb-2 leading-tight line-clamp-2" title={video.title}>{video.title}</Text>
									</div>
									<div className="relative h-[120px] bg-gray-200">
										<img src={video.thumbnail} alt={video.title} className="w-full h-full object-cover" />
										<div className="absolute inset-0 flex justify-center items-center bg-black bg-opacity-30">
											<PlayCircleOutlined className="text-white text-4xl" />
										</div>
									</div>
									<div className="p-3">
										<Text type="secondary" className="text-xs">传播效率: {video.spreadEfficiency.toFixed(2)}</Text>
										<Button
											icon={<EditOutlined />}
											className="w-full mt-2"
											// onClick={() => handleEditTitleCover(video.id)} // Add handler later
										>
											编辑标题/封面
										</Button>
									</div>
								</Card>
							))}

							{/* Add Video Button - Conditionally Rendered */}
							{selectedVideos.length < 3 && (
								<div
									className="w-[220px] h-[316px] flex flex-col justify-center items-center bg-gray-100 border border-dashed border-gray-300 rounded cursor-pointer hover:border-blue-500 hover:text-blue-500"
									onClick={openVideoSelector} // Open the drawer on click
								>
									<PlusOutlined className="text-2xl mb-2" />
									<Typography.Text>添加视频</Typography.Text>
								</div>
							)}
						</div>
					</Form.Item>
				</Form>
			</Modal>

			{/* Video Selection Drawer */}
			<VideoSelectModal
				visible={isVideoSelectVisible}
				onClose={handleVideoSelectionCancel}
				onOk={handleVideoSelectionOk}
				initialSelectedIds={selectedVideos.map(v => v.id)} // Pass current selection IDs
			/>
		</>
	);
};

export default AddPunlishPlanModal;
